/* Structures defining a thread-local-heap */

typedef struct tthreadlocalheap {

  int lock_word;		//Used to indicated whether this tlh is owned or not
  struct tthreadlocalheap* next;//Pointer to next tlh used for list of free tlhs
  int32 words[375];		//Number of words reserved for actual object allocation

} tThreadLocalHeap;
